@@ -34,19 +34,26 @@
  */
 class AnalogMeterWidget : public VolumeMeterWidget
 {
-
 public:
-    AnalogMeterWidget(QWidget *parent);
+    AnalogMeterWidget(QWidget *parent)
+        : VolumeMeterWidget(parent)
+        , startAngle(40)  // to the left from the vertical
+        , span(2 * startAngle)
+    {}
 
 protected:
-
-    void draw(QPainter *painter);
-    void drawBackground(QPainter *painter);
-    void drawTriggerIndicator(QPainter *painter);
-    void initPainter(QPainter *painter);
+    void draw (QPainter *painter);
+    void drawBackground (QPainter *painter);
+    void drawTriggerIndicator (QPainter *painter, int value);
+    void initPainter (QPainter *painter);
 
 private:
-    void prepareBackground();
+    void prepareBackground ();
+    int verticalCorrection () const;
+
+private:
+    const int startAngle;
+    const int span;
 };
 
 #endif // ANALOGMETERWIDGET_H
