@@ -30,17 +30,20 @@
  */
 class HorizontalVolumeBarWidget : public VolumeMeterWidget
 {
-
 public:
-    HorizontalVolumeBarWidget(QWidget *parent);
+    HorizontalVolumeBarWidget (QWidget *parent)
+        : VolumeMeterWidget(parent)
+    {}
 
 protected:
-    void draw(QPainter *painter);
-    void drawTriggerIndicator(QPainter *painter);
+    void draw (QPainter *painter);
+    void drawTriggerIndicator (QPainter *painter, int value);
 
 private:
-    void prepareBackground();
+    void prepareBackground ();
 
+private:
+    QRect activeArea;
 };
 
 #endif // HORIZONTALVOLUMEBARWIDGET_H
