@@ -24,12 +24,11 @@
 #include <pulse/proplist.h>
 #include <pulse/stream.h>
 
-#include "mainwindow.h"
-
 extern pa_stream *stream;
 
 void connect_to_vu_meter_stream(const char *source,
-                                MainWindow *vuMeter,
+                                void *data,
+                                int numberOfChannels,
                                 int numberOfSamples = 1);
 void disconnect_stream();
 
