@@ -23,17 +23,13 @@
 #include <pulse/context.h>
 #include <pulse/introspect.h>
 
-#include <QStringList>
-
 #include "pa_context_helper.h"
 #include "pa_streams_helper.h"
 
-void get_source_info_list_callback(pa_context *context, const pa_source_info *info, int eol, void *data);
+#if !defined(Q_WS_MAEMO_5) && !defined(Q_WS_MAEMO_6)
+class QStringList;
 
-const QStringList *get_source_names();
-
-bool pa_available();
-
-void pa_shutdown();
+const QStringList &get_source_names();
+#endif
 
 #endif //PA_UTILS_H
