@@ -24,9 +24,7 @@
 #include <QDialog>
 #include <QString>
 
-namespace Ui {
-    class SettingsDialog;
-}
+#include "ui_settingsdialog.h"
 
 class SettingsDialog : public QDialog
 {
@@ -34,7 +32,7 @@ class SettingsDialog : public QDialog
 
 public:
     explicit SettingsDialog(QWidget *parent = 0);
-    ~SettingsDialog();
+    ~SettingsDialog() {}
 
     /*
      * Constant for storing the settings paths.
@@ -48,18 +46,33 @@ public:
     const static QString    COLOR_MID_COLOR;
     const static QString    COLOR_UPPER_COLOR;
 
+    const static QString    FULL_SCREEN;
+
     const static QString    INTERPOLATION_LEVEL;
 
     const static QString    LOG_FILE_NAME;
     const static QString    LOG_LOGGING_ENABLED;
 
     const static QString    METER;
+    const static QString    SCALE;
+    const static QString    SOURCE;
+    const static QString    STEREO;
 
-    const static QString    TRIGGER;
     const static QString    TRIGGER_COMMAND;
-    const static QString    TRIGGER_COUNT;
-    const static QString    TRIGGER_VALUE;
+    const static QString    TRIGGER_COMMAND_HIGH;
+    const static QString    TRIGGER_COMMAND_LOW;
 
+    const static QString    TRIGGER_COUNT;
+    const static QString    TRIGGER_COUNT_HIGH;
+    const static QString    TRIGGER_COUNT_LOW;
+
+    const static QString    TRIGGER_EDGE_MODE;
+    const static QString    TRIGGER_ORDER;
+    const static QString    TRIGGER_STEREO_MODE;
+
+    const static QString    TRIGGER_VALUE;
+    const static QString    TRIGGER_VALUE_HIGH;
+    const static QString    TRIGGER_VALUE_LOW;
 
     /*
      * Constants containing the default settings.
@@ -73,18 +86,25 @@ public:
     const static QColor     COLOR_MID_COLOR_DEFAULT;
     const static QColor     COLOR_UPPER_COLOR_DEFAULT;
 
+    const static bool       FULL_SCREEN_DEFAULT = false;
+
     const static int        INTERPOLATION_LEVEL_DEFAULT = 0;
 
     const static QString    LOG_FILE_NAME_DEFAULT;
     const static bool       LOG_LOGGING_ENABLED_DEFAULT = false;
 
     const static int        METER_DEFAULT = 0;
+    const static int        SCALE_DEFAULT = 1;  // 0=Linear, 1=dB
+    const static int        SOURCE_DEFAULT = 0;
+    const static bool       STEREO_DEFAULT = false;
 
     const static QString    TRIGGER_COMMAND_DEFAULT;
     const static int        TRIGGER_COUNT_DEFAULT = 0;
+    const static bool       TRIGGER_EDGE_MODE_DEFAULT = false;
+    const static int        TRIGGER_ORDER_DEFAULT = 0;
+    const static int        TRIGGER_STEREO_MODE_DEFAULT = 0;
     const static int        TRIGGER_VALUE_DEFAULT = 0;
 
-
     void accept();
 
 private slots:
@@ -92,8 +112,7 @@ private slots:
     void restoreDefaults();
 
 private:
-    Ui::SettingsDialog *ui;
-
+    Ui::SettingsDialog ui;
 };
 
 #endif // SETTINGSDIALOG_H
