@@ -31,27 +31,22 @@
  */
 class VolumeLineChartWidget : public VolumeMeterWidget
 {
-
 public:
-    VolumeLineChartWidget(QWidget *parent);
-    ~VolumeLineChartWidget();
+    VolumeLineChartWidget (QWidget *parent)
+        : VolumeMeterWidget(parent, Qt::black, 4, Qt::gray, 4)
+    {}
 
-    void setDbUnit(bool b);
+    void setScale (int maxValue);
 
 protected:
-    void draw(QPainter *painter);
-    void drawTriggerIndicator(QPainter *painter);
-    void resizeEvent(QResizeEvent *event);
+    void draw (QPainter *painter);
+    void drawTriggerIndicator (QPainter *painter, int value);
 
 private:
-    void prepareBackground();
-    /**
-     * Initialize QList for volume values.
-     * @see VolumeLineChartWidget#volumeValues
-     */
-    void initValues();
+    void prepareBackground ();
 
-    QList<float> *volumeValues;
+    QRect activeArea;
+    QList<int> volumeValues;
 };
 
 #endif // VOLUMELINECHARTWIDGET_H
