@@ -27,7 +27,6 @@
 
 #define MAX_DB 110
 #define MAX_LINEAR 200
-#define RATIO 3.
 
 /**
  * Base class for all volume displays.
@@ -37,22 +36,25 @@ class VolumeMeterWidget : public QGLWidget
     Q_OBJECT
 
 public:
-    explicit VolumeMeterWidget(QWidget *parent = 0);
-    ~VolumeMeterWidget();
+    explicit VolumeMeterWidget (QWidget *parent,
+                                const QColor &col1 = Qt::black, int width1 = 8,
+                                const QColor &col2 = Qt::black, int width2 = 4);
+    ~VolumeMeterWidget ();
 
-    virtual void updateValue(int value);
-    virtual void setDbUnit(bool b);
-    virtual void setTriggerValue(int value);
+    virtual void updateValue (int value);
+    virtual void setScale (int maxValue);
+    virtual void setTriggerValues (int valueHi, int valueLo);
 
-    void setColors(QColor lower, QColor mid, QColor upper);
-    void setColorThresholds(int lower, int upper);
-    void setUseColoredScale(bool b);
+    void setColors (QColor lower, QColor mid, QColor upper);
+    void setColorThresholds (int lower, int upper);
+    void setUseColoredScale (bool b);
 
 signals:
     /**
      * This signal is triggered on a mouse release event.
      */
-    void clicked();
+    void clicked ();
+    void redraw ();
 
 protected:
     /** QImage for holding the widgets background.
@@ -61,34 +63,25 @@ protected:
      * The idea is to paint the background only when needed in order to improve the performance.
      * Ideally, the background is only re-painted on size changes.
      */
-    QImage          *background;
-    int             currentValue;
-    bool            dbUnit;
-    /** Height of the widget */
-    float           h;
-    Qt::GlobalColor triggerIndicatorColor;
-    int             triggerValue;
-    bool            useColoredScale;
-    /** Width of the widget */
-    float           w;
+    QImage       *background;
+    int          currentValue;
+    int          maximumValue;
+    /** Height and width of the widget */
+    int          h, w;
 
-    int             lowerThreshold;
-    int             upperThreshold;
+    bool         useColoredScale;
+    int          lowerThreshold;
+    int          upperThreshold;
 
-    QColor          lowerColor;
-    QColor          midColor;
-    QColor          upperColor;
+    QColor       lowerColor;
+    QColor       midColor;
+    QColor       upperColor;
 
+    const QColor defaultColor;
+    const QColor triggerIndicatorColor;
 
-    /**
-     * Calculate the current size of the widget.
-     *
-     * Calculates the widget size taking the aspect ration into account.
-     * The size will be calculated such that the displayed widget fits
-     * into the available space without being deformed.
-     * This method sets the h and w variables.
-     */
-    virtual void calculateSize();
+    const QPen   thickPen;
+    const QPen   thinPen;
 
     /**
      * Method for drawing the widgets content.
@@ -96,25 +89,27 @@ protected:
      * This is a pure virtual function that has to be implemented by all subclasses.
      * This method is responsible for painting the widgets content.
      */
-    virtual void draw(QPainter *painter) = 0;
-    virtual void drawBackground(QPainter *painter);
-    virtual void drawTriggerIndicator(QPainter *painter);
+    virtual void draw (QPainter *painter) = 0;
+    virtual void drawBackground (QPainter *painter);
+    virtual void drawTriggerIndicator (QPainter *painter, int value) = 0;
 
     /**
      * Initialize the QImage which holds the background.
      */
-    virtual void initBackground();
+    virtual void initBackground ();
+
     /**
      * Initialize the painter.
      *
      * This method sets the viewport, window etc.
      */
-    virtual void initPainter(QPainter *painter);
+    virtual void initPainter (QPainter *painter);
+
     /**
      * Method used to trigger the @ref VolumeMeterWidget#clicked() signal.
      */
-    virtual void mouseReleaseEvent(QMouseEvent *);
-    virtual void paintEvent(QPaintEvent *event);
+    virtual void mouseReleaseEvent (QMouseEvent *);
+    virtual void paintGL ();
 
     /**
      * Prepare the background.
@@ -122,9 +117,13 @@ protected:
      * Draws the background on a QImage.
      * @see VolumeMeterWidget#background
      */
-    virtual void prepareBackground();
+    virtual void prepareBackground ();
 
-    virtual void resizeEvent(QResizeEvent *event);
+    virtual void resizeEvent (QResizeEvent *event);
+
+private:
+    int          triggerValueHigh;
+    int          triggerValueLow;
 };
 
 #endif // VOLUMEMETERWIDGET_H
